@@ -1,9 +1,7 @@
 package DDC;
-BEGIN {
-  $DDC::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Visualize random bytes
-$DDC::VERSION = '0.002';
+$DDC::VERSION = '0.003';
 use strict;
 use warnings;
 use Data::Coloured qw( pc c );
@@ -23,7 +21,7 @@ DDC - Visualize random bytes
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
