@@ -1,9 +1,7 @@
 package Data::Coloured;
-BEGIN {
-  $Data::Coloured::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Visualize random ASCII data streams
-$Data::Coloured::VERSION = '0.002';
+$Data::Coloured::VERSION = '0.003';
 use strict;
 use warnings;
 use Exporter 'import';
@@ -92,7 +90,7 @@ Data::Coloured - Visualize random ASCII data streams
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
